@@ -35,14 +35,17 @@ It should be only called by the roster recovery system.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.15'
+__version__ = '0.16'
 
 import roster_core
-import tarfile
 import os
 import bz2
 import cPickle
 
+
+roster_core.core.CheckCoreVersionMatches(__version__)
+
+
 class Recover(object):
   """Roster Recovery
 
@@ -51,7 +54,7 @@ class Recover(object):
   """
   def __init__(self, username, config_instance):
     """Sets self.db_instance
-    
+
     Inputs:
       config_instance: instantiated config class object
     """
@@ -59,6 +62,8 @@ class Recover(object):
     self.config_instance = config_instance
     self.db_instance = config_instance.GetDb()
     self.core_instance = roster_core.Core(self.username, self.config_instance)
+    self.core_helper_instance = roster_core.CoreHelpers(
+         self.core_instance)
 
   def PushBackup(self, audit_log_id):
     """Restores database from sql backup with specified audit log id
@@ -67,8 +72,6 @@ class Recover(object):
       audit_log_id: integer of audit log id
     """
     backup_dir = self.config_instance.config_file['exporter']['backup_dir']
-    root_config_dir = self.config_instance.config_file[
-        'exporter']['root_config_dir']
 
     full_dump_file = bz2.BZ2File('%s/audit_log_replay_dump-%s.bz2' %
                                  (backup_dir, audit_log_id))
@@ -93,7 +96,7 @@ class Recover(object):
     audit_dict = self.db_instance.GetEmptyRowDict('audit_log')
     audit_dict['audit_log_id'] = audit_log_id
     self.db_instance.StartTransaction()
-    try: 
+    try:
       audit_log = self.db_instance.ListRow('audit_log', audit_dict)
     finally:
       self.db_instance.EndTransaction()
@@ -112,8 +115,15 @@ class Recover(object):
       data = cPickle.loads(str(audit_log[0]['data']))['replay_args']
       print 'Replaying action with id %s: %s\nwith arguments: %s' % (
           audit_log_id, action, str(data))
-      function = getattr(self.core_instance, action)
-      function(*data)
+      if( hasattr(self.core_instance, action) ):
+        function = getattr(self.core_instance, action)
+        function(*data)
+      elif( hasattr(self.core_helper_instance, action) ):
+        function = getattr(self.core_helper_instance, action)
+        function(*data)
+      else:
+        raise roster_core.errors.UnexpectedDataError(
+            "Function %s does not exist." % action)
 
   def RunAuditRange(self, audit_log_id):
     """Runs a range of audit steps
@@ -122,14 +132,13 @@ class Recover(object):
       audit_log_id: integer of audit_log_id
     """
     backup_dir = self.config_instance.config_file['exporter']['backup_dir']
-    root_config_dir = self.config_instance.config_file[
-        'exporter']['root_config_dir']
     file_list = os.listdir(backup_dir)
     db_dumps = []
 
     for fname in file_list:
       if( fname.startswith('audit_log_replay_dump-') ):
         db_dumps.append(int(fname.split('-')[1].split('.')[0]))
+    audit_id = 0
     for audit_id in reversed(sorted(db_dumps)):
       if( audit_id < audit_log_id ):
         break
