@@ -2,21 +2,21 @@
 
 # Copyright (c) 2009, Purdue University
 # All rights reserved.
-# 
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
-# 
+#
 # Redistributions of source code must retain the above copyright notice, this
 # list of conditions and the following disclaimer.
 #
 # Redistributions in binary form must reproduce the above copyright notice, this
 # list of conditions and the following disclaimer in the documentation and/or
 # other materials provided with the distribution.
-# 
+#
 # Neither the name of the Purdue University nor the names of its contributors
 # may be used to endorse or promote products derived from this software without
 # specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -35,12 +35,13 @@ to a BIND readable text form.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.15'
+__version__ = '0.16'
 
 
 import bz2
 import ConfigParser
 import datetime
+import iscpy
 import os
 import StringIO
 import shutil
@@ -56,6 +57,9 @@ from roster_core import helpers_lib
 from roster_config_manager import zone_exporter_lib
 
 
+core.CheckCoreVersionMatches(__version__)
+
+
 class Error(errors.CoreError):
   pass
 
@@ -95,69 +99,17 @@ class BindTreeExport(object):
     """Adds/Changes directory in named.conf header
 
     Inputs:
-      namedconf: string of namedconf header
-    
+      named_conf_header: string of namedconf header
+      new_directory: {}
+
     Outputs:
       string: string of namedconf header
     """
-    namedconflines = named_conf_header.split('\n')
-    found_options = False
-    in_comment = False
-
-    for line_number, line in enumerate(namedconflines):
-      if( line.strip().startswith('#') ):
-        continue
-      elif( line.strip().startswith('//') ):
-        continue
-      elif( line.strip().startswith('/*') ):
-        in_comment = True
-      elif( '*/' in line and in_comment ):
-        in_comment = False
-        continue
-      if( in_comment ):
-        continue
-      elif( line.strip().startswith('directory ') ):
-        namedconflines.pop(line_number)
-      elif( line.strip().startswith('options') ):
-        found_options = True
-
-    if( found_options ):
-      for line_number, line in enumerate(namedconflines):
-        if( line.strip().startswith('#') ):
-          continue
-        elif( line.strip().startswith('//') ):
-          continue
-        elif( line.strip().startswith('/*') ):
-          in_comment = True
-        elif( '*/' in line and in_comment ):
-          in_comment = False
-          continue
-        if( in_comment ):
-          continue
-        for char in range(len(line)):
-          if( line[char] == 'o' ):
-            if( line[char:char + len('options')] == 'options' ):
-              if( '{' not in line ):
-                temp = char 
-                while( '{' not in namedconflines[temp] ):
-                  temp += 1
-                else:
-                  line = namedconflines[temp]
-                  char += 1
-              char_temp = 0
-              while( char_temp < len(line) ):
-                if( line[char_temp] == '{' ):
-                  newline = '\tdirectory "%s";' % new_directory.rstrip('/')
-                  namedconflines.insert(line_number + 1, newline)
-                  return '\n'.join(namedconflines)
-                if( line[char_temp] == '}' ):
-                  return None
-                char_temp += 1
-              return None
-    else:
-      namedconflines.insert(-1, 'options\n{\n\tdirectory "%s";\n};\n' % (
-          new_directory))
-      return '\n'.join(namedconflines)
+    named_conf_header_contents = iscpy.ParseISCString(named_conf_header)
+    if( 'options' not in named_conf_header_contents ):
+      named_conf_header_contents['options'] = {}
+    named_conf_header_contents['options']['directory'] = '"%s"' % new_directory
+    return iscpy.MakeISC(named_conf_header_contents)
 
 
   def AddToTarFile(self, tar_file, file_name, file_string):
@@ -208,7 +160,7 @@ class BindTreeExport(object):
 
   def ExportAllBindTrees(self, force=False):
     """Exports bind trees to files
-    
+
     Inputs:
       force: boolean of if the export should continue if no changes are found
              in the database
@@ -246,7 +198,7 @@ class BindTreeExport(object):
         finally:
           self.db_instance.UnlockDb()
       finally:
-          self.db_instance.EndTransaction()
+        self.db_instance.EndTransaction()
       cooked_data = self.CookData(data)
       zone_view_assignments = {}
       for zone_view_assignment in data['zone_view_assignments']:
@@ -278,7 +230,7 @@ class BindTreeExport(object):
             self.root_config_dir.rstrip('/'), dns_server_set)
         if( not os.path.exists(named_directory) ):
           os.makedirs(named_directory)
-        dns_server_set_directory = ('%s/%s_servers/named' % 
+        dns_server_set_directory = ('%s/%s_servers/named' %
                                    (self.root_config_dir.rstrip('/'),
                                     dns_server_set))
         if( not os.path.exists(dns_server_set_directory) ):
@@ -311,7 +263,6 @@ class BindTreeExport(object):
                 cooked_data[dns_server_set]['views'][view]['zones'][zone][
                     'zone_origin'],
                 record_argument_definitions, zone, view)
-
             self.AddToTarFile(tar_file, zone_file, zone_file_string)
         named_conf_file = '%s/named.conf' % named_directory.rstrip('/')
         named_conf_file_string = self.MakeNamedConf(data, cooked_data,
@@ -345,8 +296,8 @@ class BindTreeExport(object):
       audit_log_replay_dump_file.writelines(audit_log_replay_dump)
     finally:
       audit_log_replay_dump_file.close()
-                                          
-    full_dump_file = bz2.BZ2File('%s/full_database_dump-%s.bz2' % 
+
+    full_dump_file = bz2.BZ2File('%s/full_database_dump-%s.bz2' %
                                  (self.backup_dir, log_id), 'w')
     try:
       for full_dump_index, full_dump_entry in enumerate(full_database_dump):
@@ -359,7 +310,7 @@ class BindTreeExport(object):
       shutil.rmtree(self.root_config_dir)
 
   def CookRawDump(self, raw_dump):
-    """This takes raw data from the database and turns it into a 
+    """This takes raw data from the database and turns it into a
     mysqldump-like output.
 
     Inputs:
@@ -399,7 +350,7 @@ class BindTreeExport(object):
     audit_log_replay_dump.extend(header)
 
     for table_name, table_data in raw_dump.iteritems():
-      table_lines = [] 
+      table_lines = []
       table_lines.append('DROP TABLE IF EXISTS `%s`;\n' % table_name)
       table_lines.append(table_data['schema'])
       table_lines[-1] = '%s;' % table_lines[-1]
@@ -440,8 +391,7 @@ class BindTreeExport(object):
         if( time_differential < smallest_time_differential ):
           smallest_time_differential = time_differential
           newest_config = named_config['global_options']
-
-    return newest_config
+    return iscpy.Deserialize(newest_config)
 
   def MakeNamedConf(self, data, cooked_data, dns_server_set):
     """Makes named.conf file strings
@@ -456,8 +406,9 @@ class BindTreeExport(object):
     """
     acl_dict = {}
     named_conf_lines = ['#This named.conf file is autogenerated. DO NOT EDIT']
-    named_conf_header = self.ListLatestNamedConfGlobalOptions(data, dns_server_set)
-    if( not named_conf_header ):
+    named_conf_header = self.ListLatestNamedConfGlobalOptions(
+        data, dns_server_set)
+    if( named_conf_header is None ):
       raise Error('Named conf global options missing for server set "%s"' % (
           dns_server_set))
     named_conf_header = self.NamedHeaderChangeDirectory(
@@ -498,17 +449,17 @@ class BindTreeExport(object):
         clients = [u'any;']
       named_conf_lines.append('\tmatch-clients { %s };' % ' '.join(clients))
       for zone in cooked_data[dns_server_set]['views'][view_name]['zones']:
-          named_conf_lines.append('\tzone "%s" {' % (
-              cooked_data[dns_server_set]['views'][view_name]['zones'][zone][
-                  'zone_origin'].rstrip('.')))
-          named_conf_lines.append('\t\ttype %s;' % cooked_data[
-              dns_server_set]['views'][view_name]['zones'][zone]['zone_type'])
-          named_conf_lines.append('\t\tfile "%s/named/%s/%s.db";' % (
-              self.named_dir.rstrip('/'), view_name, zone))
-          zone_options = cooked_data[dns_server_set]['views'][view_name][
-              'zones'][zone]['zone_options'].replace('\n', '\n\t\t')
-          named_conf_lines.append('\t\t%s' % zone_options.rsplit('\n\t\t', 1)[0])
-          named_conf_lines.append('\t};')
+        named_conf_lines.append('\tzone "%s" {' % (
+          cooked_data[dns_server_set]['views'][view_name]['zones'][zone][
+              'zone_origin'].rstrip('.')))
+        named_conf_lines.append('\t\ttype %s;' % cooked_data[
+            dns_server_set]['views'][view_name]['zones'][zone]['zone_type'])
+        named_conf_lines.append('\t\tfile "%s/named/%s/%s.db";' % (
+            self.named_dir.rstrip('/'), view_name, zone))
+        zone_options = cooked_data[dns_server_set]['views'][view_name][
+            'zones'][zone]['zone_options'].replace('\n', '\n\t\t')
+        named_conf_lines.append('\t\t%s' % zone_options.rsplit('\n\t\t', 1)[0])
+        named_conf_lines.append('\t};')
       named_conf_lines.append('};')
     return '\n'.join(named_conf_lines)
 
@@ -534,7 +485,7 @@ class BindTreeExport(object):
 
     Outputs:
       tuple of two dictionaries:
-        dictionary of raw data keyed by data name with values of dicts 
+        dictionary of raw data keyed by data name with values of dicts
             containing values of that type's attributes
         dictionary of the raw dump keyed by data name with values of
             dicts containing the db dump keyed by row, column, and schema
@@ -759,11 +710,11 @@ class BindTreeExport(object):
                   if( not zone_name in cooked_data[
                         dns_server_set_name]['views'][view_name]['zones'] ):
                     cooked_data[dns_server_set_name]['views'][view_name][
-                        'zones'][zone_name]= {}
+                        'zones'][zone_name] = {}
                   if( 'records' not in cooked_data[dns_server_set_name][
                           'views'][view_name]['zones'][zone_name] ):
-                      cooked_data[dns_server_set_name]['views'][view_name][
-                          'zones'][zone_name]['records'] = []
+                    cooked_data[dns_server_set_name]['views'][view_name][
+                        'zones'][zone_name]['records'] = []
 
                   for record in sorted_records[(
                       zone_name, view_dependency_name)].values():
@@ -781,15 +732,14 @@ class BindTreeExport(object):
                           zone_name, view_dependency_name)].values())
 
                   cooked_data[dns_server_set_name]['views'][view_name][
-                      'zones'][zone_name]['zone_origin'] = punycode_lib.Uni2Puny(
-                          zone['zone_origin'])
+                      'zones'][zone_name]['zone_origin'] = (
+                          punycode_lib.Uni2Puny(zone['zone_origin']))
 
                   cooked_data[dns_server_set_name]['views'][view_name][
-                      'zones'][zone_name]['zone_options'] = zone['zone_options']
+                      'zones'][zone_name]['zone_options'] = iscpy.Deserialize(zone['zone_options'])
 
                   cooked_data[dns_server_set_name]['views'][view_name][
                       'zones'][zone_name]['zone_type'] = zone[
                           'zone_view_assignments_zone_type']
 
     return cooked_data
-
